@@ -1,4 +1,4 @@
-/* Copyright 2007, 2008 Matthew Barnes
+/* Copyright 2007-2009 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -21,7 +21,7 @@
 #include <errno.h>
 #include <signal.h>
 #include <string.h>
-#include <wait.h>
+#include <sys/wait.h>
 
 #include "gva-error.h"
 #include "gva-util.h"
